@@ -90,6 +90,18 @@ class DatasetUpdater:
         # Step 1: Determine which competitions to process
         competitions_list = self._get_competitions(competition, last_season)
 
+        # Define fixed paths BEFORE the loop (these don't have placeholders)
+        matches_csv_path = self.paths["matches"]
+        players_csv_path = self.paths["players"]
+        keepers_csv_path = self.paths["keepers"]
+        teams_csv_path = self.paths["teams"]
+        
+        # Ensure parent folders exist for fixed paths
+        for _p in [matches_csv_path, players_csv_path, keepers_csv_path, teams_csv_path]:
+            _parent = os.path.dirname(_p)
+            if _parent:
+                os.makedirs(_parent, exist_ok=True)
+
         matches = pd.DataFrame()
 
         # Step 2: Process each competition
@@ -97,6 +109,7 @@ class DatasetUpdater:
             comp_name = comp_info["name"]
             comp_country = comp_info["country"]
 
+            # Only format the ranking path (it has placeholders)
             formatted_paths = _format_paths(
                 self.paths,
                 last_season=last_season,
@@ -104,17 +117,12 @@ class DatasetUpdater:
                 competition=comp_name,
             )
 
-            matches_csv_path = formatted_paths["matches"]
-            players_csv_path = formatted_paths["players"]
-            keepers_csv_path = formatted_paths["keepers"]
             ranking_csv_path = formatted_paths["ranking"]
-            teams_csv_path = formatted_paths["teams"]
-
-            # --- Ensure parent folders exist ---
-            for _p in [matches_csv_path]:
-                _parent = os.path.dirname(_p)
-                if _parent:
-                    os.makedirs(_parent, exist_ok=True)
+            
+            # Ensure parent folder exists for ranking
+            _parent = os.path.dirname(ranking_csv_path)
+            if _parent:
+                os.makedirs(_parent, exist_ok=True)
 
             print(f"            Processing competition: {comp_name} - {comp_country}")
 
@@ -122,11 +130,11 @@ class DatasetUpdater:
                 comp_matches = self._process_competition(
                     comp_name,
                     comp_country,
-                    matches_csv_path,
-                    players_csv_path,
-                    keepers_csv_path,
-                    ranking_csv_path,
-                    teams_csv_path,
+                    matches_csv_path,   # Fixed path, same for all competitions
+                    players_csv_path,   # Fixed path, same for all competitions
+                    keepers_csv_path,   # Fixed path, same for all competitions
+                    ranking_csv_path,   # Variable path per competition
+                    teams_csv_path,     # Fixed path, same for all competitions
                     days,
                     last_season,
                 )
@@ -140,8 +148,10 @@ class DatasetUpdater:
 
         # Check if any matches were found across ALL competitions
         if matches.empty:
+            print("            No new matches found")
             return pd.DataFrame()
 
+        # Read existing matches, combine with new ones, and save
         all_matches = (
             pd.read_csv(matches_csv_path)
             if os.path.exists(matches_csv_path)
@@ -149,10 +159,11 @@ class DatasetUpdater:
         )
         
         final_all_matches = pd.concat([matches, all_matches], ignore_index=True)
-        
         final_all_matches = sort_by_match_datetime(final_all_matches)
         
         final_all_matches.to_csv(matches_csv_path, index=False, encoding="utf-8")
+        
+        print(f"            Saved {len(matches)} new matches. Total matches in dataset: {len(final_all_matches)}")
 
         return matches
 
