@@ -826,31 +826,31 @@ class Settings:
             },
         },
         # ==================== PORTUGESH COMPETITIONS ====================
-        "primeira_liga": {
-            "country": "portugal",
-            "yellow_cards_suspensions": {
-                "type": "staggered_thresholds",
-                "scope": "same_competition_only",
-                "ban_matches": 1,
-                "thresholds": [5, 9, 12],
-                "after_last_threshold": {"every_n_cards": 3},
-            },
-            "information_scraping_urls": {
-                "matches": "https://fbref.com/en/comps/32/{last_season[0]}/schedule/{last_season[0]}-Primeira-Liga-Scores-and-Fixtures",
-                "ranking": "https://fbref.com/es/comps/33/{last_season[0]}/{last_season[0]}-Primeira-Liga-Stats",
-                "fotmob": "https://www.fotmob.com/leagues/61/fixtures/liga-portugal?group=by-date&season={last_season[0]}&group=by-date&page={page}",
-            },
-            "betting_scraping_urls": {
-                "betclic": "https://www.betclic.fr/football-sfootball/angl-premier-league-c3", # Cambiar
-                "winamax": "https://www.winamax.fr/paris-sportifs/sports/1/1/1",
-                "unibet": "https://www.unibet.fr/sport/football/angleterre/premier-league?filter=Top+Paris&subFilter=R%C3%A9sultat+du+match",
-                "parionssport": "https://www.enligne.parionssport.fdj.fr/paris-football/angleterre/premier-league",
-                "pmu": "https://parisportif.pmu.fr/home/wrapper/events?fId=1&activeSportId=1&leagues=%5B261%5D&boost=%5B%5D",
-                "bwin": "https://www.bwin.fr/fr/sports/football-4/paris-sportifs/angleterre-14/premier-league-102841",
-                "netbet": "https://www.netbet.fr/football/angleterre/premier-league",
-                "betsson": "https://betsson.fr/fr/competitions/football/premier-league?competition_id=55768.1",
-            },
-        },
+        # "primeira_liga": {
+        #     "country": "portugal",
+        #     "yellow_cards_suspensions": {
+        #         "type": "staggered_thresholds",
+        #         "scope": "same_competition_only",
+        #         "ban_matches": 1,
+        #         "thresholds": [5, 9, 12],
+        #         "after_last_threshold": {"every_n_cards": 3},
+        #     },
+        #     "information_scraping_urls": {
+        #         "matches": "https://fbref.com/en/comps/32/{last_season[0]}/schedule/{last_season[0]}-Primeira-Liga-Scores-and-Fixtures",
+        #         "ranking": "https://fbref.com/es/comps/33/{last_season[0]}/{last_season[0]}-Primeira-Liga-Stats",
+        #         "fotmob": "https://www.fotmob.com/leagues/61/fixtures/liga-portugal?group=by-date&season={last_season[0]}&group=by-date&page={page}",
+        #     },
+        #     "betting_scraping_urls": {
+        #         "betclic": "https://www.betclic.fr/football-sfootball/angl-premier-league-c3", # Cambiar
+        #         "winamax": "https://www.winamax.fr/paris-sportifs/sports/1/1/1",
+        #         "unibet": "https://www.unibet.fr/sport/football/angleterre/premier-league?filter=Top+Paris&subFilter=R%C3%A9sultat+du+match",
+        #         "parionssport": "https://www.enligne.parionssport.fdj.fr/paris-football/angleterre/premier-league",
+        #         "pmu": "https://parisportif.pmu.fr/home/wrapper/events?fId=1&activeSportId=1&leagues=%5B261%5D&boost=%5B%5D",
+        #         "bwin": "https://www.bwin.fr/fr/sports/football-4/paris-sportifs/angleterre-14/premier-league-102841",
+        #         "netbet": "https://www.netbet.fr/football/angleterre/premier-league",
+        #         "betsson": "https://betsson.fr/fr/competitions/football/premier-league?competition_id=55768.1",
+        #     },
+        # },
         # ==================== EUROPEAN COMPETITIONS ====================
         "uefa_champions_league": {
             "country": "europe",
